aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src
diff options
context:
space:
mode:
Diffstat (limited to 'Eigen/src')
-rw-r--r--Eigen/src/Geometry/Transform.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/Eigen/src/Geometry/Transform.h b/Eigen/src/Geometry/Transform.h
index 58afd8993..78d45a7cb 100644
--- a/Eigen/src/Geometry/Transform.h
+++ b/Eigen/src/Geometry/Transform.h
@@ -201,8 +201,13 @@ protected:
public:
- /** Default constructor without initialization of the coefficients. */
- inline Transform() { }
+ /** Default constructor without initialization of the meaningfull coefficients.
+ * If Mode==Affine, then the last row is set to [0 ... 0 1] */
+ inline Transform()
+ {
+ if (Mode==Affine)
+ makeAffine();
+ }
inline Transform(const Transform& other)
{